Crink
=====

Intended as an entry to [Spring Thing 2025](https://www.springthing.net/2025/).

In accordance with the rules of the competition, this project is in private development until March 2025.

This package is a placeholder until a public release is available.

Getting Python
--------------

TBD.


Getting Crink
-------------

TBD.


Running Crink
-------------

TBD.
